# ChargeFunction

**Note**: This field is only available if you have the [Unbilled Usage](https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Bill_for_usage_or_prepaid_products/Advanced_Consumption_Billing/Unbilled_Usage) feature enabled.    Define what type of charge it is in Advanced consumption billing. * Standard: Normal charge with no Prepayment or Commitment or Drawdown. * Prepayment: For recurring charges. Unit or currency based prepaid charge. * CommitmentTrueUp: For recurring charges. Currency based minimum commitment charge. * Drawdown: For usage charges. Drawdown from prepaid funds. * DrawdownAndCreditCommitment: For usage charges. Drawdown from prepaid funds and then credit to minimum commitment funds. * CreditCommitment: For usage charges. Credit to minimum commitment funds. 

## Enum

* `STANDARD` (value: `'Standard'`)

* `PREPAYMENT` (value: `'Prepayment'`)

* `COMMITMENTTRUEUP` (value: `'CommitmentTrueUp'`)

* `DRAWDOWN` (value: `'Drawdown'`)

* `CREDITCOMMITMENT` (value: `'CreditCommitment'`)

* `DRAWDOWNANDCREDITCOMMITMENT` (value: `'DrawdownAndCreditCommitment'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


